@@ -1,4 +1,4 @@
-// Copyright 2018 The CUE Authors
+// Copyright 2018 CUE Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -44,7 +44,7 @@ import (
 var requestedVersion = os.Getenv("CUE_SYNTAX_OVERRIDE")
 
 func defaultConfig() (*config, error) {
-	reg, err := getRegistry()
+	reg, err := getCachedRegistry()
 	if err != nil {
 		return nil, err
 	}
@@ -778,13 +778,16 @@ func buildToolInstances(binst []*build.Instance) ([]*cue.Instance, error) {
 }
 
 func buildTools(cmd *Command, args []string) (*cue.Instance, error) {
-	cfg := &load.Config{
-		Tools: true,
+	cfg, err := defaultConfig()
+	if err != nil {
+		return nil, err
 	}
+	loadCfg := *cfg.loadCfg
+	loadCfg.Tools = true
 	f := cmd.cmd.Flags()
-	setTags(cfg, f, cmd.cmd.Parent().Flags())
+	setTags(&loadCfg, f, cmd.cmd.Parent().Flags())
 
-	binst := loadFromArgs(args, cfg)
+	binst := loadFromArgs(args, &loadCfg)
 	if len(binst) == 0 {
 		return nil, nil
 	}
